summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/Kolinewidthaction.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /lib/kofficeui/Kolinewidthaction.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficeui/Kolinewidthaction.h')
-rw-r--r--lib/kofficeui/Kolinewidthaction.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/kofficeui/Kolinewidthaction.h b/lib/kofficeui/Kolinewidthaction.h
index 31991fb4..a2b1dfe4 100644
--- a/lib/kofficeui/Kolinewidthaction.h
+++ b/lib/kofficeui/Kolinewidthaction.h
@@ -35,20 +35,20 @@ class KOFFICEUI_EXPORT KoLineWidthAction : public KoSelectAction
/** Constructs a KoLineWidthAction with a text and an icon.
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
- KoLineWidthAction(const TQString& text, const TQString& icon, TQObject* tqparent = 0, const char* name = 0);
+ KoLineWidthAction(const TQString& text, const TQString& icon, TQObject* parent = 0, const char* name = 0);
/** Same as above, but it also connects a slot to the selectionChanged(int) signal.
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
* @param receiver The SLOT's tqparent.
* @param slot The TQT_SLOT to invoke when a lineWidthChanged(double) signal is emited.
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
KoLineWidthAction(const TQString& text, const TQString& icon, const TQObject* receiver,
- const char* slot, TQObject* tqparent, const char* name = 0);
+ const char* slot, TQObject* parent, const char* name = 0);
~KoLineWidthAction();
/** Returns the currently selected line width */
@@ -90,7 +90,7 @@ class KoLineWidthChooser : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- KoLineWidthChooser(TQWidget* tqparent = 0, const char* name = 0);
+ KoLineWidthChooser(TQWidget* parent = 0, const char* name = 0);
~KoLineWidthChooser();
/** Returns the selected line width in points. */
@@ -35,20 +35,20 @@ class KOFFICEUI_EXPORT KoLineWidthAction : public KoSelectAction
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -35,20 +35,20 @@ class KOFFICEUI_EXPORT KoLineWidthAction : public KoSelectAction
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
- * @param receiver The SLOT's tqparent.
+ * @param receiver The SLOT's parent.
* @param slot The TQT_SLOT to invoke when a lineWidthChanged(double) signal is emited.
@@ -35,20 +35,20 @@ class KOFFICEUI_EXPORT KoLineWidthAction : public KoSelectAction
* @param slot The TQT_SLOT to invoke when a lineWidthChanged(double) signal is emited.
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/